@@ -138,15 +138,15 @@ class Drush:
         if isdir(self._path) and isdir(path_join(self._path, 'sites')):
             with pushd(self._path):
                 site_dirs = [x
-                            for x in os.listdir('sites')
-                            if isdir(os.path.join('sites', x)) and
-                            x not in ['all', 'default']]
+                             for x in os.listdir('sites')
+                             if isdir(os.path.join('sites', x)) and
+                             x not in ['all', 'default']]
                 for item in site_dirs:
                     self._uris.append('http://%s' % (item))
 
                 self._uris.sort()
 
-    def command(self, string_as_is, ignore_errors=False):
+    def command(self, string_as_is, ignore_errors=False, once=False):
         """Runs a drush command string. If the class is not in verbose mode,
             -q argument will be added
            ignore_errors may want to be used for commands that exit with
@@ -173,6 +173,9 @@ class Drush:
                 if not ignore_errors:
                     raise e
 
+            if once:
+                return
+
             for uri in self._uris:
                 if re.match(r'^https?\://default$', uri):
                     continue
@@ -251,7 +254,7 @@ class Drush:
 
         os.makedirs(path_join(self._path, 'sites', 'all', 'libraries'))
 
-    def _handle_dl(self, command_line):
+    def _handle_dl(self, command_line, ignore_errors=False):
         try:
             sp.check_call(command_line)
         except sp.CalledProcessError as e:
@@ -260,8 +263,8 @@ class Drush:
                 pass
 
             raise DrushError('Non-zero status %d. Run in verbose mode and'
-                                'check output for [error] line' %
-                                (e.returncode))
+                             'check output for [error] line' %
+                             (e.returncode))
 
     def dl(self, module_names, cache=True, ignore_errors=False):
         """Downloads modules.
@@ -293,11 +296,12 @@ class Drush:
             'registry_rebuild',
         ]
 
-        if len(module_names) == 1 and module_names[0].lower() in dir_exceptions:
-            return self._handle_dl(command_line)
+        if len(module_names) == 1 and \
+                module_names[0].lower() in dir_exceptions:
+            return self._handle_dl(command_line, ignore_errors)
 
         with pushd(self._path):
-            self._handle_dl(command_line)
+            self._handle_dl(command_line, ignore_errors)
 
     def rr(self):
         """Rebuild registry front-end method."""
@@ -345,11 +349,12 @@ class Drush:
 
         for (key, value) in dict_of_vars.items():
             value = php.serialize(value)
-            c.execute('INSERT INTO variable (name, value) VALUES (%s, %s) ON DUPLICATE KEY UPDATE value=%s', args=(key, value, value,))
+            c.execute('INSERT INTO variable (name, value) VALUES '
+                      '(%s, %s) ON DUPLICATE KEY UPDATE value=%s',
+                      args=(key, value, value,))
 
         mysql_connection.commit()
 
-
     def updb(self):
         """Update database front-end method. Use with caution."""
         return self.command('updb -y')
